@@ -22,7 +22,7 @@ def dependency(function: callable, expand_mapping: bool = False):
         @wraps(function)
         async def _function(*args, **kwargs):
             if isinstance(result := await function(*args, **kwargs), Mapping):
-                _context[_dependencies].extend(result)
+                _context[_dependencies].update(result)
 
             return result
     else:
